
/**************************************************************************
** 
** File name   : replication_partisan.do
** Date        : August 20th, 2012
** Author      : Christina J. Schneider (cjschneider@ucsd.edu) and Johannes 
					Urpelainen (ju2178@columbia.edu)
** Paper	   : Partisan Heterogeneity and International Cooperation: 
					The Case of the European Development Fund
** Purpose     : Replicate Tables 3, 5, 6, and 7
** Requires    : replication_partisan.dta, replication_partisan_period.dta
					replication_partisan.do
** Output      : partisan_replication.log
**
**************************************************************************/ 


version 12.1

#delimit ; 

log using replication_partisan, replace;
use replication_partisan, replace;


********************************;

**TABLE 2, MODEL 1**;

xtpcse edf_ln partisan_std  gdppercap_eu100  blaid_gdp repvotes unemploymentrate
 ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8 id_9 id_10 id_11 
 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 2, MODEL 2**;

xtpcse edf_percap partisan_std  gdppercap_eu100  blaid_gdp repvotes 
	unemploymentrate ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8
	 id_9 id_10 id_11 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 2, MODEL 3**;

xtpcse edf_ln edf_lnlag partisan_std  gdppercap_eu100  blaid_gdp repvotes 
	unemploymentrate ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8
	 id_9 id_10 id_11 id_12 id_13 id_14, pairwise;

**TABLE 2, MODEL 4**;

xtpcse edf_ln partisan_std  gdppercap_eu100  blaid_gdp repvotes unemploymentrate
 ctotreceived_percap time_trend id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8 id_9 
 id_10 id_11 id_12 id_13 id_14, pairwise correlation(psar1);


**TABLE 2, MODEL 5**;

use replication_partisan_period, replace;

gen period=0;
replace period=1 if year<1980;
replace period=2 if year>=1980 & year<1985;
replace period=3 if year>=1985 & year<1990;
replace period=4 if year>=1990 & year<1995;
replace period=5 if year>=1995 & year<2000;
replace period=6 if year>=2000;

sort country_id year;

egen edf_period=mean(edf_ln), by(country_id period);
egen partisan_period=mean(partisan_std), by(period);
egen gdp_period=mean(gdppercap_eu100), by(country_id period);
egen blaid_period=mean(blaid_gdp), by(country_id period);
egen repvotes_period=mean(repvotes), by(country_id period);
egen unemploymentrate_period=mean(unemploymentrate), by(country_id period);
egen ctotreceived_period=mean(ctotreceived_percap), by(country_id period);

gen help=0;
by country_id period, sort: replace help=1 if year==1977;
by country_id period, sort: replace help=1 if year==1980;
by country_id period, sort: replace help=1 if year==1985;
by country_id period, sort: replace help=1 if year==1990;
by country_id period, sort: replace help=1 if year==1995;
by country_id period, sort: replace help=1 if year==2000;

xtpcse edf_period partisan_period gdp_period  blaid_period repvotes_period 
unemploymentrate_period ctotreceived_period id_1 id_2 id_3 id_4 id_5 id_6 id_7 
id_8 id_9 id_10 id_11 id_12 id_13 id_14 if help==1, pairwise correlation(psar1);



********************************;

use replication_partisan, replace;

**TABLE 3, MODEL 6**;

xtpcse edf_ln partisan_std partisan_mean gdppercap_eu100  blaid_gdp repvotes 
	unemploymentrate ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8
	 id_9 id_10 id_11 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 3, MODEL 7**;

xtpcse edf_ln partisan_std partisan_mean hetmean gdppercap_eu100  blaid_gdp 
	repvotes unemploymentrate ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 
	id_7 id_8 id_9 id_10 id_11 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 3, MODEL 8**;

xtpcse edf_ln partisan_range gdppercap_eu100  blaid_gdp repvotes unemploymentrate
 ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8 id_9 id_10 id_11 
 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 3, MODEL 9**;

xtpcse edf_ln partisan_std_ptf gdppercap_eu100  blaid_gdp repvotes 
	unemploymentrate ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8
	 id_9 id_10 id_11 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 3, MODEL 10**;

xtpcse edf_ln partisan_std_ej gdppercap_eu100  blaid_gdp repvotes unemploymentrate
 ctotreceived_percap id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8 id_9 id_10 id_11 
 id_12 id_13 id_14, pairwise correlation(psar1);


********************************;

**TABLE 4, MODEL 11**;

xtpcse edf_ln partisan_std  gdppercap_eu100  blaid_gdp repvotes unemploymentrate
 ctotreceived_percap gdp_std id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8 id_9 id_10
  id_11 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 4, MODEL 12**;

xtpcse edf_ln partisan_std  gdppercap_eu100  blaid_gdp repvotes unemploymentrate
 ctotreceived_percap eusupport_std id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8 id_9 
 id_10 id_11 id_12 id_13 id_14, pairwise correlation(psar1);

**TABLE 4, MODEL 13**;

xtpcse edf_ln partisan_std  gdppercap_eu100  blaid_gdp repvotes unemploymentrate
 ctotreceived_percap euintegration_std id_1 id_2 id_3 id_4 id_5 id_6 id_7 id_8 
 id_9 id_10 id_11 id_12 id_13 id_14, pairwise correlation(psar1);

********************************;



log close;
exit;
